Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LogProvider ¶
type LogProvider interface {
Error(ctx context.Context, report bool, args ...interface{})
Warn(ctx context.Context, report bool, args ...interface{})
Info(ctx context.Context, report bool, args ...interface{})
Debug(ctx context.Context, report bool, args ...interface{})
// Record metrics, or events with metrics
Record(ctx context.Context, metrics map[string]interface{})
RecordEvent(ctx context.Context, eventName string, metrics map[string]interface{})
// Wait for any asynchronous logging processes to complete; good to call before exiting program
Wait()
}
Directories
¶
| Path | Synopsis |
|---|---|
|
This package assists with chaining together providers by providing default implementations for LogProvider interface methods that don't panic if we're the last in the chain.
|
This package assists with chaining together providers by providing default implementations for LogProvider interface methods that don't panic if we're the last in the chain. |
|
This package provides a basic dumb logger to get bootstrapped with
|
This package provides a basic dumb logger to get bootstrapped with |
|
This package provides a concrete implementation of LogProvider using Logrus
|
This package provides a concrete implementation of LogProvider using Logrus |
|
This extracts merry Values into logger Fields, then passes along to the base logger
|
This extracts merry Values into logger Fields, then passes along to the base logger |
|
This package provides newrelic metric/request reporting via ContextLogger
|
This package provides newrelic metric/request reporting via ContextLogger |
|
This adds a field to log reports showing where the logger was called from
|
This adds a field to log reports showing where the logger was called from |
|
This logger reports errors to Rollbar if they came in via {Error,Warn,Info}Report, then passes through for logging by the base logger, if any.
|
This logger reports errors to Rollbar if they came in via {Error,Warn,Info}Report, then passes through for logging by the base logger, if any. |
Click to show internal directories.
Click to hide internal directories.