rollbar

package
v2.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2020 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

This logger reports errors to Rollbar if they came in via {Error,Warn,Info}Report, then passes through for logging by the base logger, if any. It uses the stack stored by merry, if the error is a merry error; otherwise it generates a new one based on the reporting callstack.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LogProvider

func LogProvider(nextProvider providers.LogProvider) (providers.LogProvider, error)

func WithRequest

func WithRequest(ctx context.Context, req *http.Request) log.ContextLogger

Types

This section is empty.

Jump to