Documentation
¶
Overview ¶
This logger reports errors to Rollbar if they came in via {Error,Warn,Info}Report, then passes through for logging by the base logger, if any. It uses the stack stored by merry, if the error is a merry error; otherwise it generates a new one based on the reporting callstack.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LogProvider ¶
func LogProvider(nextProvider providers.LogProvider) (providers.LogProvider, error)
func WithRequest ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.